@@ -4,7 +4,7 @@
 */
 
 
-#include "compress.h"
+#include "dact.h"
 #include "comp_delta.h"
 #include "buffer.h"
 #include <stdio.h>
@@ -21,7 +21,7 @@
 	out_block	- Where to put data after compression.
 	blk_size	- Size of prev_block and curr_block.
 */
-int comp_delta_algo(int mode, char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_delta_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
 			return(comp_delta_compress(prev_block,curr_block,out_block,blk_size));
@@ -35,7 +35,7 @@ int comp_delta_algo(int mode, char *prev_block, char *curr_block, char *out_bloc
 	}
 }
 
-int comp_delta_compress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_delta_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	int i,x=0,y=0;
 	char Val;
 	unsigned char CurrByte, PrevByte;
@@ -73,7 +73,7 @@ int comp_delta_compress(char *prev_block, char *curr_block, char *out_block, int
 	return(x+1);
 }
 
-int comp_delta_decompress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_delta_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	int i=0,x=0;
 	unsigned char CurrByte;
 	unsigned char DeltaByte;
