@@ -5,7 +5,7 @@
 */
 
 
-#include "compress.h"
+#include "dact.h"
 #include "comp_fail.h"
 #include <stdio.h>
 #include <unistd.h>
@@ -20,7 +20,7 @@
 	out_block	- Where to put data after compression.
 	blk_size	- Size of prev_block and curr_block.
 */
-int comp_fail_algo(int mode, char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_fail_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
 			return(comp_fail_compress(prev_block,curr_block,out_block,blk_size));
@@ -34,11 +34,11 @@ int comp_fail_algo(int mode, char *prev_block, char *curr_block, char *out_block
 	}
 }
 
-int comp_fail_compress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_fail_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	return(-1);
 }
 
-int comp_fail_decompress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_fail_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	printf("You tried to decompress a file with an algorithm that is not compiled into your version.  Output will be unusable.\n");
 	return(0);
 }
