@@ -8,7 +8,7 @@
 */
 
 
-#include "compress.h"
+#include "dact.h"
 #include "comp_plain.h"
 #include <stdio.h>
 #include <unistd.h>
@@ -23,7 +23,7 @@
 	out_block	- Where to put data after compression.
 	blk_size	- Size of prev_block and curr_block.
 */
-int comp_plain_algo(int mode, char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_plain_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
 			return(comp_plain_compress(prev_block,curr_block,out_block,blk_size));
@@ -37,12 +37,12 @@ int comp_plain_algo(int mode, char *prev_block, char *curr_block, char *out_bloc
 	}
 }
 
-int comp_plain_compress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_plain_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	memcpy(out_block,curr_block,blk_size);
 	return(blk_size);
 }
 
-int comp_plain_decompress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_plain_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	memcpy(out_block,curr_block,blk_size);
 	return(blk_size);
 }
