@@ -4,7 +4,7 @@
 */
 
 
-#include "compress.h"
+#include "dact.h"
 #include "comp_rle.h"
 #include <stdio.h>
 #include <unistd.h>
@@ -19,7 +19,7 @@
 	out_block	- Where to put data after compression.
 	blk_size	- Size of prev_block and curr_block.
 */
-int comp_rle_algo(int mode, char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_rle_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
 			return(comp_rle_compress(prev_block,curr_block,out_block,blk_size));
@@ -33,11 +33,11 @@ int comp_rle_algo(int mode, char *prev_block, char *curr_block, char *out_block,
 	}
 }
 
-int comp_rle_compress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_rle_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	return(-1);
 }
 
-int comp_rle_decompress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_rle_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	printf("Not yet supported.\n");
 	return(0);
 }
