@@ -5,7 +5,7 @@
 */
 
 
-#include "compress.h"
+#include "dact.h"
 #ifdef USE_ZLIB
 #include "comp_zlib.h"
 #include <stdio.h>
@@ -22,7 +22,7 @@
 	out_block	- Where to put data after compression.
 	blk_size	- Size of prev_block and curr_block.
 */
-int comp_zlib_algo(int mode, char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_zlib_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
 			return(comp_zlib_compress(prev_block,curr_block,out_block,blk_size));
@@ -36,7 +36,7 @@ int comp_zlib_algo(int mode, char *prev_block, char *curr_block, char *out_block
 	}
 }
 
-int comp_zlib_compress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_zlib_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	unsigned long dest_size;
 	int retval;
 	dest_size=(int) ((float) (blk_size*1.01)+13);
@@ -48,7 +48,7 @@ int comp_zlib_compress(char *prev_block, char *curr_block, char *out_block, int
 	return(dest_size);
 }
 
-int comp_zlib_decompress(char *prev_block, char *curr_block, char *out_block, int blk_size) {
+int comp_zlib_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	unsigned long dest_size;
 	int retval;
 
